@@ -57,6 +57,12 @@ function showProfiles(refresh = false) {
 
   document.title = pageTitle;
   sendWithResponse("getProfilesInfo", {}, response => {
+    // Show window-bar only when profile picker is open as modal (not browser tab)
+    const windowBar = document.querySelector(".window-bar");
+    if (windowBar && response.enableCSD) {
+      windowBar.classList.add("visible");
+    }
+
     // Root
     const portal = document.querySelector(".ProfilePicker");
     clearElement(portal);
@@ -475,4 +481,13 @@ function showProfiles(refresh = false) {
   });
 }
 
-document.addEventListener("DOMContentLoaded", () => showProfiles());
+document.addEventListener("DOMContentLoaded", () => {
+  showProfiles();
+  // Handle window close button
+  const closeButton = document.getElementById("window-close-btn");
+  if (closeButton) {
+    closeButton.addEventListener("click", () => {
+      sendWithResponse("closeProfilePicker", {}, () => {});
+    });
+  }
+});
